@@ -4,6 +4,7 @@ import re
 import sys
 from datetime import datetime
 from typing import Union, Type, Optional, Callable, Awaitable
+from urllib.parse import urljoin
 
 from discord import (
     Member,
@@ -14,6 +15,7 @@ from discord import (
     Invite,
     PartialEmoji,
     Role,
+    Thread,
 )
 from discord.abc import Messageable, User
 from discord.ext.commands import Cog as DiscordCog, Bot, Context, CommandError
@@ -135,6 +137,9 @@ class Cog(DiscordCog):
     async def on_command_error(self, ctx: Context, error: CommandError):
         pass
 
+    async def on_thread_join(self, thread: Thread):
+        pass
+
 
 def check_dependencies(cogs: list[Cog]) -> set[Type[Cog]]:
     """
@@ -262,6 +267,6 @@ def get_documentation(cog: Union[Cog, Type[Cog]]) -> Optional[str]:
             r"^cogs\.[a-zA-Z\d\-_]+\.([a-zA-Z\d\-_]+)\.([a-zA-Z\d\-_]+)\.cog$",
             cls.__module__,
         ):
-            return f"https://docs.pydrocsid.ml/cogs/{match.group(1)}/{match.group(2)}/"
+            return urljoin(Config.DOCUMENTATION_URL, f"cogs/{match.group(1)}/{match.group(2)}/")
 
     return None
