@@ -1,13 +1,26 @@
 import asyncio
+import time
 from contextlib import asynccontextmanager
-from copy import deepcopy
-from typing import Union
-
-from discord import User, Member, Embed, Message, Forbidden, TextChannel
-from discord.abc import Messageable
-from discord.ext.commands import Command, Context, CommandError
+from typing import Union, cast
 
 from PyDrocsid.async_thread import gather_any
+from discord import (
+    User,
+    Member,
+    Embed,
+    Message,
+    Forbidden,
+    TextChannel,
+    ButtonStyle,
+    ui,
+    NotFound,
+    InteractionResponse,
+    Interaction,
+)
+from discord.abc import Messageable
+from discord.ext.commands import Command, Context, CommandError
+from discord.ui import View, Button
+
 from PyDrocsid.command_edit import link_response
 from PyDrocsid.emojis import name_to_emoji
 from PyDrocsid.environment import REPLY, MENTION_AUTHOR
@@ -77,7 +90,7 @@ def make_error(message: str, user: Union[Member, User, None] = None) -> Embed:
     embed = Embed(title=t.error, colour=MaterialColors.error, description=str(message))
 
     if user:
-        embed.set_author(name=str(user), icon_url=user.avatar_url)
+        embed.set_author(name=str(user), icon_url=user.display_avatar.url)
 
     return embed
 
@@ -91,7 +104,12 @@ async def can_run_command(command: Command, ctx: Context) -> bool:
         return False
 
 
-async def reply(ctx: Union[Context, Message, Messageable], *args, no_reply: bool = False, **kwargs) -> Message:
+async def reply(
+    ctx: Context | Message | Messageable | InteractionResponse,
+    *args,
+    no_reply: bool = False,
+    **kwargs,
+) -> Message | None:
     """
     Reply to a message and link response to this message.
 
@@ -102,6 +120,10 @@ async def reply(ctx: Union[Context, Message, Messageable], *args, no_reply: bool
     :return: the message that was sent
     """
 
+    if isinstance(ctx, InteractionResponse):
+        await ctx.send_message(*args, **kwargs, ephemeral=True)
+        return None
+
     if isinstance(channel := ctx.channel if isinstance(ctx, (Message, Context)) else ctx, TextChannel):
         try:
             check_message_send_permissions(
@@ -141,48 +163,94 @@ async def add_reactions(ctx: Union[Context, Message], *emojis: str):
             break
 
 
+class Confirm(View):
+    def __init__(self, user: Member | User, danger: bool, timeout: int, countdown: bool):
+        super().__init__(timeout=timeout)
+
+        self.user = user
+        self.result = None
+        self.countdown = countdown
+        if countdown:
+            self.set_countdown(timeout)
+
+        if danger:
+            self.children: list[Button]
+            self.children[0].style = ButtonStyle.danger
+            self.children[1].style = ButtonStyle.secondary
+
+    def set_countdown(self, value: int):
+        button = cast(Button, self.children[1])
+        button.label = t.cancel + f" ({value})"
+
+    async def run(self, message: Message) -> bool | None:
+        async def countdown():
+            timeout = cast(int, self.timeout)
+            ts = time.time() + timeout
+            while (delta := ts - time.time()) > 0:
+                await asyncio.sleep(delta % 1)
+                if delta < 1:
+                    break
+                self.set_countdown(int(delta))
+                await gather_any(asyncio.sleep(1), message.edit(view=self))
+
+            self.stop()
+
+        if self.countdown:
+            task = asyncio.create_task(countdown())
+            await self.wait()
+            task.cancel()
+        else:
+            await self.wait()
+
+        if not self.result:
+            cast(Button, self.children[1]).label = t.canceled
+
+        for item in self.children:
+            item.disabled = True
+
+        try:
+            await message.edit(view=self)
+        except NotFound:
+            return None
+
+        return self.result
+
+    async def interaction_check(self, interaction: Interaction) -> bool:
+        if interaction.user == self.user:
+            return True
+
+        await interaction.response.send_message("Please do not press this button again!", ephemeral=True)
+        return False
+
+    @ui.button(label=t.confirm, style=ButtonStyle.success)
+    async def confirm(self, button: Button, _):
+        self.result = True
+        self.stop()
+        button.label = t.confirmed
+        cast(Button, self.children[1]).label = t.cancel
+
+    @ui.button(label=t.cancel, style=ButtonStyle.danger)
+    async def cancel(self, button: Button, _):
+        self.result = False
+        self.stop()
+        button.label = t.canceled
+
+
 @asynccontextmanager
-async def confirm(ctx: Context, embed: Embed, timeout: int = 300):
+async def confirm(ctx: Context, embed: Embed, danger: bool = False, timeout: int = 20, countdown: bool = False):
     """
     Send an embed, add confirmation reactions (:white_check_mark: and :x:) and wait for a reaction of the author.
     Yield True or False, depending on whether the author reacted with :white_check_mark: or :x:.
     Update the message if the embed has been modified and remove all reactions.
     """
 
-    # create a copy of the embed so that we can check later if it has been edited
-    _embed: dict = deepcopy(embed.to_dict())
-
     # send embed and add reactions
-    message: Message = await reply(ctx, embed=embed)
-    await message.add_reaction(yes := name_to_emoji["white_check_mark"])
-    await message.add_reaction(no := name_to_emoji["x"])
+    view = Confirm(ctx.author, danger, timeout, countdown)
+    message: Message = await reply(ctx, embed=embed, view=view)
 
-    # wait for either a confirmation reaction, or the deletion of the message, or the expiration of the timeout
-    i, result = await gather_any(
-        ctx.bot.wait_for(
-            "reaction_add",
-            check=lambda r, u: r.message == message and u == ctx.author and str(r) in [yes, no],
-        ),
-        ctx.bot.wait_for("message_delete", check=lambda msg: msg == message),
-        asyncio.sleep(timeout),
-    )
+    result = await view.run(message)
 
-    if i == 0:  # confirmation reaction
-        reaction, _ = result
-        yield str(reaction) == yes, message
-    else:  # message deleted or timeout expired
+    if result is None:
         yield False, None
-
-    if i == 1:  # message deleted
-        return
-
-    # edit message if embed has been modified
-    if embed.to_dict() != _embed:
-        await message.edit(embed=embed)
-
-    # remove reactions
-    try:
-        await message.clear_reactions()
-    except Forbidden:
-        await message.remove_reaction(yes, ctx.bot.user)
-        await message.remove_reaction(no, ctx.bot.user)
+    else:
+        yield result, message
